pub struct BBoxDevice { /* private fields */ }Expand description
A bounding box tracker that records the extent of all drawing operations.
Implementations
Sourceimpl BBoxDevice
impl BBoxDevice
pub fn new(page_transform: Matrix) -> Self
Sourcepub fn bbox(&self) -> Option<Rect>
pub fn bbox(&self) -> Option<Rect>
Get the computed bounding box, or None if no content was drawn.
Sourcepub fn extend_rect(&mut self, x: f64, y: f64, w: f64, h: f64)
pub fn extend_rect(&mut self, x: f64, y: f64, w: f64, h: f64)
Extend the bounding box with a rectangle in PDF user space.
Sourcepub fn process_ops(&mut self, ops: &[ContentOp])
pub fn process_ops(&mut self, ops: &[ContentOp])
Process content stream operations to compute bounding box.