BBox Device: a lightweight device that tracks the bounding box of all drawing operations without actually rendering pixels.
Structs
- BBox
Device - A bounding box tracker that records the extent of all drawing operations.
Functions
- compute_
page_ bbox - Compute the content bounding box for a page (in PDF user space coordinates).